@@ -1,4 +1,4 @@
-/*  $Id: archive.c 8788 2009-11-15 09:27:11Z iulius $
+/*  $Id: archive.c 9658 2014-08-28 18:59:18Z iulius $
 **
 **  Read batchfiles on standard input and archive them.
 */
@@ -254,7 +254,7 @@ build_path(const char *group, const char *number, struct config *config,
         tm = localtime(&now);
         year = tm->tm_year + 1900;
         month = tm->tm_mon + 1;
-        buffer_sprintf(path, true, "/%04d%02d", year, month);
+        buffer_append_sprintf(path, "/%04d%02d", year, month);
     } else {
         buffer_append(path, "/", 1);
         buffer_append(path, number, strlen(number));
@@ -285,7 +285,7 @@ process_article(ARTHANDLE *art, const char *token, struct config *config)
         warn("cannot find Xref: header in %s", token);
         return;
     }
-    end = wire_endheader(start, art->data + art->len);
+    end = wire_endheader(start, art->data + art->len - 1);
     xref = xstrndup(start, end - start);
     for (p = xref; *p != '\0'; p++)
         if (*p == '\r' || *p == '\n')
