@@ -1,4 +1,4 @@
-/*  $Id: inndf.c 9891 2015-06-03 19:08:50Z iulius $
+/*  $Id: inndf.c 10305 2018-12-02 14:21:56Z iulius $
 **
 **  Reports free kilobytes (not disk blocks) or free inodes.
 **
@@ -332,7 +332,7 @@ main(int argc, char *argv[])
             printf("Space used is meaningless for the %s method\n",
                    innconf->ovmethod);
         else
-            printf("%.2f%% overview space used\n", used);
+            printf("%.2f%% overview space used\n", (double) used);
     }
     if (overview != NULL)
         overview_close(overview);
