@@ -1,4 +1,4 @@
-/*  $Id: expire.c 10012 2016-05-05 12:41:10Z iulius $
+/*  $Id: expire.c 10153 2017-06-05 12:28:01Z iulius $
 **
 **  Expire news articles.
 */
@@ -54,7 +54,9 @@ static long		EXPstillhere;
 static struct history	*History;
 static char		*NHistory;
 
-static void CleanupAndExit(bool Server, bool Paused, int x);
+static void CleanupAndExit(bool Server, bool Paused, int x)
+    __attribute__ ((__noreturn__));
+static void Usage(void) __attribute__ ((__noreturn__));
 
 static int EXPsplit(char *p, char sep, char **argv, int count);
 
