@@ -1,4 +1,4 @@
-/*  $Id: feedone.c 8903 2010-01-17 18:21:56Z iulius $
+/*  $Id: feedone.c 10022 2016-05-05 12:49:59Z iulius $
 **
 **  Connect to the NNTP server and feed one article.
 */
@@ -6,6 +6,7 @@
 #include "config.h"
 #include "clibrary.h"
 #include <errno.h>
+#include <time.h>
 
 #include "inn/libinn.h"
 #include "inn/messages.h"
@@ -27,7 +28,7 @@ GetFromServer(buff, size, text)
     char	*text;
 {
     if (fgets(buff, size, FromServer) == NULL)
-        sysdie("s", text);
+        sysdie("%s", text);
     if (Tracing)
 	printf("S: %s", buff);
 }
@@ -83,7 +84,6 @@ main(ac, av)
     bool	PostMode;
 
     /* Set defaults. */
-    mesgid[0] = '\0';
     PostMode = false;
     message_program_name = "feedone";
 
