@@ -1,4 +1,4 @@
-/*  $Id: inews.c 10017 2016-05-05 12:44:17Z iulius $
+/*  $Id: inews.c 10304 2018-12-02 14:05:50Z iulius $
 **
 **  Send an article (prepared by someone on the local site) to the
 **  master news server.
@@ -34,7 +34,6 @@
 #define HEADER_DELTA		20
 #define GECOSTERM(c)		\
 	    ((c) == ',' || (c) == ';' || (c) == ':' || (c) == LPAREN)
-#define HEADER_STRLEN		998
 
 typedef enum _HEADERTYPE {
     HTobs,
@@ -64,6 +63,8 @@ static const char * const BadDistribs[] = {
     BAD_DISTRIBS
 };
 
+static void Usage(void) __attribute__ ((__noreturn__));
+
 static HEADER	Table[] = {
     /* 	Name			Canset	Type	*/
     {	"Path",			true,	HTstd,  0, NULL },
@@ -122,7 +123,7 @@ static HEADER	Table[] = {
 static void
 QuitServer(int x)
 {
-    char	buff[HEADER_STRLEN];
+    char	buff[MED_BUFFER];
     char	*p;
 
     if (Spooling)
@@ -196,13 +197,22 @@ TrimSpaces(char *p)
 static char *
 NextHeader(char *p)
 {
-    for ( ; ; p++) {
-	if ((p = strchr(p, '\n')) == NULL)
+    char *q;
+    for (q = p; ; p++) {
+        if ((p = strchr(p, '\n')) == NULL) {
             die("article is all headers");
-	if (!ISWHITE(p[1])) {
-	    *p = '\0';
-	    return p + 1;
-	}
+        }
+        /* Check the maximum length of a single line. */
+        if (p - q + 1 > MAXARTLINELENGTH) {
+            die("header line too long");
+        }
+        /* Check if there is a continuation line for the header. */
+        if (ISWHITE(p[1])) {
+            q = p + 1;
+            continue;
+        }
+        *p = '\0';
+        return p + 1;
     }
 }
 
@@ -394,7 +404,7 @@ CheckControl(char *ctrl)
     for (ctrl = p; *p && !ISWHITE(*p); p++)
 	continue;
     if (p == ctrl)
-        die("emtpy control message");
+        die("empty control message");
     save = *p;
     *p = '\0';
 
@@ -598,9 +608,11 @@ ProcessHeaders(bool AddOrg, int linecount, struct passwd *pwp)
                 HDR(_path) = concat(Exclusions, PATHFLUFF, (char *) 0);
 	}
 	else if (innconf->server != NULL) {
-	    if ((p = GetFQDN(innconf->domain)) == NULL)
-                sysdie("cannot get hostname");
+	    p = inn_getfqdn(innconf->domain);
+	    if (p == NULL)
+		sysdie("cannot get hostname");
 	    HDR(_path) = concat(Exclusions, p, "!", PATHFLUFF, (char *) 0);
+	    free(p);
 	}
 	else {
 	    HDR(_path) = concat(Exclusions, PATHFLUFF, (char *) 0);
@@ -796,7 +808,7 @@ OfferArticle(char *buff, bool Authorized)
 {
     fprintf(ToServer, "post\r\n");
     SafeFlush(ToServer);
-    if (fgets(buff, HEADER_STRLEN, FromServer) == NULL)
+    if (fgets(buff, MED_BUFFER, FromServer) == NULL)
         sysdie(Authorized ? "Can't offer article to server (authorized)"
                           : "Can't offer article to server");
     return atoi(buff);
@@ -866,8 +878,8 @@ main(int ac, char *av[])
     struct passwd	*pwp;
     char		*article;
     char		*deadfile;
-    char		buff[HEADER_STRLEN];
-    char		SpoolMessage[HEADER_STRLEN];
+    char		buff[MED_BUFFER];
+    char		SpoolMessage[MED_BUFFER];
     bool		DoSignature;
     bool		AddOrg;
     size_t		Length;
@@ -987,7 +999,7 @@ main(int ac, char *av[])
 	setbuf(ToServer, xmalloc(BUFSIZ));
 	fprintf(ToServer, "mode reader\r\n");
 	SafeFlush(ToServer);
-	if (fgets(buff, HEADER_STRLEN, FromServer) == NULL)
+	if (fgets(buff, MED_BUFFER, FromServer) == NULL)
             sysdie("cannot tell server we're reading");
 	if ((j = atoi(buff)) != NNTP_ERR_COMMAND)
 	    i = j;
@@ -1024,13 +1036,6 @@ main(int ac, char *av[])
     /* Do final checks. */
     if (i == 0 && HDR(_control) == NULL)
         die("article is empty");
-    for (hp = Table; hp < ARRAY_END(Table); hp++)
-	if (hp->Value && (int)strlen(hp->Value) + hp->Size > HEADER_STRLEN)
-            die("%s header is too long", hp->Name);
-    for (i = 0; i < OtherCount; i++)
-	if ((int)strlen(OtherHeaders[i]) > HEADER_STRLEN)
-            die("header too long (maximum length is %d): %.40s...",
-                HEADER_STRLEN, OtherHeaders[i]);
 
     if (Dump) {
 	/* Write the headers and a blank line. */
