@@ -1,4 +1,4 @@
-/*  $Id: hisv6.c 9094 2010-08-05 19:48:31Z iulius $
+/*  $Id: hisv6.c 10305 2018-12-02 14:21:56Z iulius $
 **
 **  History v6 implementation against the history API.
 **
@@ -46,6 +46,7 @@
 #include "hisv6.h"
 #include "hisv6-private.h"
 #include "inn/dbz.h"
+#include "inn/fdflag.h"
 #include "inn/innconf.h"
 #include "inn/timer.h"
 #include "inn/qio.h"
@@ -78,9 +79,9 @@ hisv6_errloc(char *s, size_t line, off_t offset)
 {
     if (offset != -1) {
 	/* really we want an autoconf test for %ll/%L/%I64, sigh */
-	sprintf(s, "@%.0f", (double)offset);
+        snprintf(s, HISV6_MAX_LOCATION, "@%lu", (unsigned long)offset);
     } else {
-	sprintf(s, ":%lu", (unsigned long)line);
+        snprintf(s, HISV6_MAX_LOCATION, ":%lu", (unsigned long)line);
     }
 }
 
@@ -314,7 +315,7 @@ hisv6_reopen(struct hisv6 *h)
 	    hisv6_closefiles(h);
 	    goto fail;
 	}
-	close_on_exec(fileno(h->writefp), true);
+	fdflag_close_exec(fileno(h->writefp), true);
     }
 
     /* Open the history file for reading. */
@@ -324,7 +325,7 @@ hisv6_reopen(struct hisv6 *h)
 	hisv6_closefiles(h);
 	goto fail;
     }
-    close_on_exec(h->readfd, true);
+    fdflag_close_exec(h->readfd, true);
     
     /* if there's no current dbz owner, claim it here */
     if (hisv6_dbzowner == NULL) {
