@@ -1,4 +1,4 @@
-/* $Id: clibrary.h 10246 2018-02-16 21:12:42Z iulius $
+/* $Id: clibrary.h 10287 2018-05-21 12:42:24Z iulius $
  *
  * Standard system includes and portability adjustments.
  *
@@ -77,6 +77,11 @@
 /* Get the bool type. */
 #include "portable/stdbool.h"
 
+/* In case uint32_t and associated limits weren't defined. */
+#ifndef UINT32_MAX
+# define UINT32_MAX 4294967295UL
+#endif
+
 /* Windows provides snprintf under a different name. */
 #ifdef _WIN32
 # define snprintf _snprintf
