@@ -1,4 +1,4 @@
-/*  $Id: innperl.h 6527 2003-10-20 22:31:30Z rra $
+/*  $Id: innperl.h 9933 2015-08-28 19:27:38Z iulius $
 **
 **  Declarations for embedded Perl.
 */
@@ -11,6 +11,10 @@
 
 #include "config.h"
 
+/* Suppress the float-equal gcc warning because of SvTRUE that
+   compares floats to 0.0 in Perl core code. */
+#pragma GCC diagnostic ignored "-Wfloat-equal"
+
 BEGIN_DECLS
 
 /* Provide an alternate version of newXS that takes const char strings for the
