@@ -1,4 +1,4 @@
-/*  $Id: innd.h 10263 2018-03-10 14:51:53Z iulius $
+/*  $Id: innd.h 10282 2018-05-14 12:42:14Z iulius $
 **
 **  Many of the data types used here have abbreviations, such as CT for a
 **  channel type.  Here are a list of the conventions and meanings:
@@ -862,6 +862,11 @@ extern void		PYmode(OPERATINGMODE mode, OPERATINGMODE newmode,
 			       char *reason);
 extern void		PYsetup(void);
 extern void		PYclose(void);
+# if PY_MAJOR_VERSION >= 3
+extern PyMODINIT_FUNC   PyInit_INN(void);
+# else
+extern void             PyInit_INN(void);
+# endif
 #endif /* DO_PYTHON */
 
 END_DECLS
