@@ -1,4 +1,4 @@
-/*  $Id: lc.c 8307 2009-01-31 08:30:38Z iulius $
+/*  $Id: lc.c 9841 2015-05-02 16:27:37Z iulius $
 **
 **  Routines for the local connect channel.  Create a Unix-domain stream
 **  socket that processes on the local server connect to.  Once the
@@ -14,7 +14,7 @@
 
 
 #ifdef HAVE_UNIX_DOMAIN_SOCKETS
-# include <sys/un.h>
+# include "portable/socket-unix.h"
 
 static char	*LCpath = NULL;
 static CHANNEL	*LCchan;
@@ -51,9 +51,8 @@ LCreader(CHANNEL *cp)
 **  Write-done function.  Shouldn't happen.
 */
 static void
-LCwritedone(CHANNEL *unused)
+LCwritedone(CHANNEL *unused UNUSED)
 {
-    unused = unused;		/* ARGSUSED */
     syslog(L_ERROR, "%s internal LCwritedone", LogName);
 }
 
