@@ -1,4 +1,4 @@
-/*  $Id: nc.c 9630 2014-05-14 17:39:56Z iulius $
+/*  $Id: nc.c 10305 2018-12-02 14:21:56Z iulius $
 **
 **  Routines for the NNTP channel.  Other channels get the descriptors which
 **  we turn into NNTP channels, and over which we speak NNTP.
@@ -15,6 +15,8 @@
 #define BAD_COMMAND_COUNT	10
 
 
+extern bool laxmid;
+
 /*
 **  An entry in the dispatch table.  The name, and implementing function,
 **  of every command we support.
@@ -88,6 +90,9 @@ static NCDISPATCH NCcommands[] = {
        READER command. */
     COMMAND_READER("ARTICLE"),
     COMMAND_READER("BODY"),
+#if defined(HAVE_ZLIB)
+    COMMAND_READER("COMPRESS"),
+#endif /* HAVE_ZLIB */
     COMMAND_READER("DATE"),
     COMMAND_READER("GROUP"),
     COMMAND_READER("HDR"),
@@ -284,9 +289,9 @@ NCpostit(CHANNEL *cp)
            cp->Refused - cp->Refused_checkpoint,
            cp->Rejected - cp->Rejected_checkpoint,
            cp->Duplicate - cp->Duplicate_checkpoint,
-           cp->Size - cp->Size_checkpoint,
-           cp->DuplicateSize - cp->DuplicateSize_checkpoint,
-           cp->RejectSize - cp->RejectSize_checkpoint);
+           (double) (cp->Size - cp->Size_checkpoint),
+           (double) (cp->DuplicateSize - cp->DuplicateSize_checkpoint),
+           (double) (cp->RejectSize - cp->RejectSize_checkpoint));
     cp->Reported = 0;
     cp->Started_checkpoint = Now.tv_sec;
     cp->Received_checkpoint = cp->Received;
@@ -355,7 +360,7 @@ NChead(CHANNEL *cp)
         return;
     }
 
-    if (!IsValidMessageID(cp->av[1], true)) {
+    if (!IsValidMessageID(cp->av[1], true, laxmid)) {
         xasprintf(&buff, "%d Syntax error in message-ID", NNTP_ERR_SYNTAX);
         NCwritereply(cp, buff);
         free(buff);
@@ -421,7 +426,7 @@ NCstat(CHANNEL *cp)
         return;
     }
 
-    if (!IsValidMessageID(cp->av[1], true)) {
+    if (!IsValidMessageID(cp->av[1], true, laxmid)) {
         xasprintf(&buff, "%d Syntax error in message-ID", NNTP_ERR_SYNTAX);
         NCwritereply(cp, buff);
         free(buff);
@@ -619,6 +624,11 @@ NCcapabilities(CHANNEL *cp)
         WCHANappend(cp, NCterm, strlen(NCterm));
     }
 
+    if (cp->IsAuthenticated) {
+        WCHANappend(cp, "XBATCH", 6);
+        WCHANappend(cp, NCterm, strlen(NCterm));
+    }
+
     NCwritereply(cp, NCdot);
 }
 
@@ -632,14 +642,14 @@ NCihave(CHANNEL *cp)
 {
     char        *buff = NULL;
 #if defined(DO_PERL) || defined(DO_PYTHON)
-    char	*filterrc;
+    char	*filterrc = NULL;
     size_t	msglen;
 #endif /*defined(DO_PERL) || defined(DO_PYTHON) */
 
     cp->Ihave++;
     cp->Start = cp->Next;
 
-    if (!IsValidMessageID(cp->av[1], false)) {
+    if (!IsValidMessageID(cp->av[1], false, laxmid)) {
         /* Return 435 here instead of 501 for compatibility reasons. */
         xasprintf(&buff, "%d Syntax error in message-ID", NNTP_FAIL_IHAVE_REFUSE);
         NCwritereply(cp, buff);
@@ -1791,7 +1801,7 @@ NCcheck(CHANNEL *cp)
     char                *buff = NULL;
     size_t		idlen, msglen;
 #if defined(DO_PERL) || defined(DO_PYTHON)
-    char		*filterrc;
+    char		*filterrc = NULL;
 #endif /* DO_PERL || DO_PYTHON */
 
     cp->Check++;
@@ -1808,8 +1818,9 @@ NCcheck(CHANNEL *cp)
             cp->Sendid.size = MED_BUFFER;
         cp->Sendid.data = xmalloc(cp->Sendid.size);
     }
-    if (!IsValidMessageID(cp->av[1], false)) {
-	snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s",
+    if (!IsValidMessageID(cp->av[1], false, laxmid)) {
+	snprintf(cp->Sendid.data, cp->Sendid.size,
+                 "%d %s Syntax error in message-ID",
                  NNTP_FAIL_CHECK_REFUSE, cp->av[1]);
 	NCwritereply(cp, cp->Sendid.data);
 	syslog(L_NOTICE, "%s bad_messageid %s", CHANname(cp),
@@ -1820,7 +1831,7 @@ NCcheck(CHANNEL *cp)
     if ((innconf->refusecybercancels) && (strncmp(cp->av[1], "<cancel.", 8) == 0)) {
 	cp->Refused++;
 	cp->Check_cybercan++;
-	snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s",
+	snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s Cyberspam cancel",
                  NNTP_FAIL_CHECK_REFUSE, cp->av[1]);
 	NCwritereply(cp, cp->Sendid.data);
 	return;
@@ -1843,8 +1854,8 @@ NCcheck(CHANNEL *cp)
     filterrc = PLmidfilter(cp->av[1]);
     if (filterrc) {
 	cp->Refused++;
-	snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s",
-                 NNTP_FAIL_CHECK_REFUSE, cp->av[1]);
+	snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s %.200s",
+                 NNTP_FAIL_CHECK_REFUSE, cp->av[1], filterrc);
 	NCwritereply(cp, cp->Sendid.data);
 	return;
     }
@@ -1855,8 +1866,8 @@ NCcheck(CHANNEL *cp)
     filterrc = PYmidfilter(cp->av[1], idlen);
     if (filterrc) {
 	cp->Refused++;
-	snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s",
-                 NNTP_FAIL_CHECK_REFUSE, cp->av[1]);
+	snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s %.200s",
+                 NNTP_FAIL_CHECK_REFUSE, cp->av[1], filterrc);
 	NCwritereply(cp, cp->Sendid.data);
 	return;
     }
@@ -1865,23 +1876,23 @@ NCcheck(CHANNEL *cp)
     if (HIScheck(History, cp->av[1]) || cp->Ignore) {
 	cp->Refused++;
 	cp->Check_got++;
-	snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s",
+	snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s Duplicate",
                  NNTP_FAIL_CHECK_REFUSE, cp->av[1]);
 	NCwritereply(cp, cp->Sendid.data);
     } else if (WIPinprogress(cp->av[1], cp, true)) {
 	cp->Check_deferred++;
 	if (cp->NoResendId) {
 	    cp->Refused++;
-	    snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s",
+	    snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s Do not resend",
                      NNTP_FAIL_CHECK_REFUSE, cp->av[1]);
 	} else {
-	    snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s",
+	    snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s Retry later",
                      NNTP_FAIL_CHECK_DEFER, cp->av[1]);
 	}
 	NCwritereply(cp, cp->Sendid.data);
     } else {
 	cp->Check_send++;
-	snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s",
+	snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s Send it",
                  NNTP_OK_CHECK, cp->av[1]);
 	NCwritereply(cp, cp->Sendid.data);
     }
@@ -1902,7 +1913,7 @@ NCtakethis(CHANNEL *cp)
     size_t  idlen, msglen;
     WIP     *wp;
 #if defined(DO_PERL) || defined(DO_PYTHON)
-    char    *filterrc;
+    char    *filterrc = NULL;
 #endif /* DO_PERL || DO_PYTHON */
 
     cp->Takethis++;
@@ -1922,7 +1933,7 @@ NCtakethis(CHANNEL *cp)
     idlen = strlen(mid);
     msglen = idlen + 5; /* 3 digits + space + id + null. */
 
-    if (!IsValidMessageID(mid, false)) {
+    if (!IsValidMessageID(mid, false, laxmid)) {
         syslog(L_NOTICE, "%s bad_messageid %s", CHANname(cp),
                MaxLength(mid, mid));
         returncode = NNTP_FAIL_TAKETHIS_REJECT;
@@ -1959,9 +1970,20 @@ NCtakethis(CHANNEL *cp)
             cp->Sendid.size = MED_BUFFER;
         cp->Sendid.data = xmalloc(cp->Sendid.size);
     }
+
     /* Save ID for later NACK or ACK. */
+#if defined(DO_PERL) || defined(DO_PYTHON)
+    if (filterrc != NULL) {
+        snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s %.200s",
+                 returncode, mid, filterrc);
+    } else {
+        snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s",
+                 returncode, mid);
+    }
+#else
     snprintf(cp->Sendid.data, cp->Sendid.size, "%d %s",
              returncode, mid);
+#endif /* defined(DO_PERL) || defined(DO_PYTHON) */
 
     cp->ArtBeg = Now.tv_sec;
     cp->State = CSgetheader;
