@@ -1,4 +1,4 @@
-/*  $Id: newsfeeds.c 9170 2011-01-24 22:12:54Z iulius $
+/*  $Id: newsfeeds.c 10122 2016-11-25 22:39:35Z iulius $
 **
 **  Routines for the in-core data structures for the newsfeeds file.
 */
@@ -842,14 +842,7 @@ SITEfunnelpatch(void)
 	    result = false;
 	    continue;
 	}
-	if (funnel->FNLnames.data == NULL) {
-	    funnel->FNLnames.size = length;
-	    funnel->FNLnames.data = xmalloc(length);
-	}
-	else if (funnel->FNLnames.size != length) {
-	    funnel->FNLnames.size = length;
-            funnel->FNLnames.data = xrealloc(funnel->FNLnames.data, length);
-	}
+	buffer_resize(&funnel->FNLnames, length);
 	sp->Funnel = funnel - Sites;
     }
 
