@@ -1,4 +1,4 @@
-/*  $Id: perl.c 9483 2013-06-06 20:10:20Z iulius $
+/*  $Id: perl.c 10305 2018-12-02 14:21:56Z iulius $
 **
 **  Perl filtering support for innd.
 **
@@ -39,7 +39,9 @@
 #include "innd.h"
 
 #include <EXTERN.h>
+#pragma GCC diagnostic ignored "-Wredundant-decls"
 #include <perl.h>
+#pragma GCC diagnostic warning "-Wredundant-decls"
 #include <XSUB.h>
 #include "ppport.h"
 
@@ -71,6 +73,7 @@ PLartfilter(const ARTDATA *data, char *artBody, long artLen, int lines)
     char *      p;
     static char buf[256];
     bool        failure;
+    SV *        errsv;
 
     if (!PerlFilterActive) return NULL;
     filter = perl_get_cv("filter_art", 0);
@@ -89,7 +92,7 @@ PLartfilter(const ARTDATA *data, char *artBody, long artLen, int lines)
        since it could potentially be quite large.  In testing, this produced
        a 17% speed improvement over making a copy of the article body
        for a fairly heavy filter.
-       Available since Perl 5.7.1, newSVpvn_share allows to avoid such
+       Available since Perl 5.7.1, newSVpvn_share allows avoiding such
        a copy (getting round its use for older versions of Perl leads
        to unreliable SV * bodies as for regexps).  And for Perl not to
        compute a hash for artBody, we give it "42". */
@@ -114,11 +117,12 @@ PLartfilter(const ARTDATA *data, char *artBody, long artLen, int lines)
 
     /* Check $@, which will be set if the sub died. */
     buf[0] = '\0';
-    if (SvTRUE(ERRSV)) {
+    errsv = ERRSV;
+    if (SvTRUE(errsv)) {
         failure = true;
         syslog(L_ERROR, "Perl function filter_art died on article %s: %s",
                HDR_FOUND(HDR__MESSAGE_ID) ? HDR(HDR__MESSAGE_ID) : "?",
-               SvPV(ERRSV, PL_na));
+               SvPV(errsv, PL_na));
         (void) POPs;
     } else {
         failure = false;
@@ -154,6 +158,7 @@ PLmidfilter(char *messageID)
     char        *p;
     static char buf[256];
     bool        failure;
+    SV *        errsv;
 
     if (!PerlFilterActive) return NULL;
     filter = perl_get_cv("filter_messageid", 0);
@@ -170,10 +175,11 @@ PLmidfilter(char *messageID)
 
     /* Check $@, which will be set if the sub died. */
     buf[0] = '\0';
-    if (SvTRUE(ERRSV)) {
+    errsv = ERRSV;
+    if (SvTRUE(errsv)) {
         failure = true;
         syslog(L_ERROR, "Perl function filter_messageid died on id %s: %s",
-               messageID, SvPV(ERRSV, PL_na));
+               messageID, SvPV(errsv, PL_na));
         (void) POPs;
     } else {
         failure = false;
@@ -200,12 +206,13 @@ PLmidfilter(char *messageID)
 **  mode and the reason.
 */
 void
-PLmode(OPERATINGMODE Mode, OPERATINGMODE NewMode, char *reason)
+PLmode(OPERATINGMODE CurrentMode, OPERATINGMODE NewMode, char *reason)
 {
     dSP;
     HV          *mode;
     CV          *filter;
     bool        failure;
+    SV *        errsv;
 
     filter = perl_get_cv("filter_mode", 0);
     if (!filter) return;
@@ -214,13 +221,13 @@ PLmode(OPERATINGMODE Mode, OPERATINGMODE NewMode, char *reason)
        the reason in $mode{reason}. */
     mode = perl_get_hv("mode", 1);
 
-    if (Mode == OMrunning)
+    if (CurrentMode == OMrunning)
         (void) hv_store(mode, "Mode", 4, newSVpv("running", 7), 0);
-    if (Mode == OMpaused)
+    if (CurrentMode == OMpaused)
         (void) hv_store(mode, "Mode", 4, newSVpv("paused", 6), 0);
-    if (Mode == OMthrottled)
+    if (CurrentMode == OMthrottled)
         (void) hv_store(mode, "Mode", 4, newSVpv("throttled", 9), 0);
-    if (Mode == OMshutdown)
+    if (CurrentMode == OMshutdown)
         (void) hv_store(mode, "Mode", 4, newSVpv("shutdown", 8), 0);
 
     if (NewMode == OMrunning)
@@ -244,10 +251,11 @@ PLmode(OPERATINGMODE Mode, OPERATINGMODE NewMode, char *reason)
     SPAGAIN;
 
     /* Check $@, which will be set if the sub died. */
-    if (SvTRUE(ERRSV)) {
+    errsv = ERRSV;
+    if (SvTRUE(errsv)) {
         failure = true;
         syslog(L_ERROR, "Perl function filter_mode died: %s",
-                SvPV(ERRSV, PL_na));
+                SvPV(errsv, PL_na));
         (void) POPs;
     } else {
         failure = false;
