@@ -1,4 +1,4 @@
-/*  $Id: python.c 9581 2013-12-09 20:07:03Z iulius $
+/*  $Id: python.c 10305 2018-12-02 14:21:56Z iulius $
 **
 **  Embed Python in the style of innd's Perl stuff.
 **
@@ -32,13 +32,27 @@
  *  and before any standard headers are included (because Python may
  *  define some pre-processor definitions which affect the standard
  *  headers on some systems). */
+#pragma GCC diagnostic ignored "-Wredundant-decls"
 #include "Python.h"
+#pragma GCC diagnostic warning "-Wredundant-decls"
 
 /*  Define Py_ssize_t when it does not exist (Python < 2.5.0). */
 #if PY_VERSION_HEX < 0x02050000
   typedef int Py_ssize_t;
 #endif
 
+#if PY_MAJOR_VERSION >= 3
+# define PyInt_FromLong PyLong_FromLong
+# define PyString_AS_STRING PyUnicode_AsUTF8
+# define PyString_FromStringAndSize PyBytes_FromStringAndSize
+# define PyString_InternFromString PyUnicode_InternFromString
+# define PYBUFF_FROMMEMORY(str, len) \
+      PyMemoryView_FromMemory((str), (len), PyBUF_WRITE)
+#else
+# define PYBUFF_FROMMEMORY(str, len) \
+      PyBuffer_FromMemory((str), (len))
+#endif
+
 #include "clibrary.h"
 
 #include "inn/innconf.h"
@@ -54,7 +68,7 @@ PyObject	*PYFilterModule = NULL;
 PyObject	*PYheaders = NULL;
 PyObject	**PYheaditem;
 PyObject	**PYheadkey;
-PyObject	*PYpathkey, *PYlineskey, *PYbodykey;
+PyObject	*PYlineskey, *PYbodykey;
 
 /*  External functions. */
 PyObject	*msgid_method = NULL;
@@ -124,7 +138,7 @@ PYartfilter(const ARTDATA *data, char *artBody, long artLen, int lines)
     hdrnum = 0;
     for (i = 0 ; i < MAX_ARTHEADER ; i++) {
 	if (HDR_FOUND(i)) {
-	    PYheaditem[hdrnum] = PyBuffer_FromMemory(HDR(i), HDR_LEN(i));
+            PYheaditem[hdrnum] = PYBUFF_FROMMEMORY(HDR(i), HDR_LEN(i));
 	} else
 	    PYheaditem[hdrnum] = Py_None;
 	PyDict_SetItem(PYheaders, PYheadkey[hdrnum], PYheaditem[hdrnum]);
@@ -133,7 +147,7 @@ PYartfilter(const ARTDATA *data, char *artBody, long artLen, int lines)
 
     /* ...then the body... */
     if (artLen && artBody != NULL)
-        PYheaditem[hdrnum] = PyBuffer_FromMemory(artBody, --artLen);
+        PYheaditem[hdrnum] = PYBUFF_FROMMEMORY(artBody, --artLen);
     else
         PYheaditem[hdrnum] = Py_None;
     PyDict_SetItem(PYheaders, PYbodykey, PYheaditem[hdrnum++]);
@@ -196,7 +210,7 @@ PYmidfilter(char *messageID, int msglen)
 **  Tell the external module about innd's state.
 */
 void
-PYmode(OPERATINGMODE Mode, OPERATINGMODE NewMode, char *reason)
+PYmode(OPERATINGMODE CurrentMode, OPERATINGMODE NewMode, char *reason)
 {
     PyObject	*result;
     char	oldmode[10], newmode[10];
@@ -204,7 +218,7 @@ PYmode(OPERATINGMODE Mode, OPERATINGMODE NewMode, char *reason)
     if (!PythonFilterActive || PYFilterObject == NULL || mode_method == NULL)
 	return;
 
-    switch (Mode) {
+    switch (CurrentMode) {
     default:		strlcpy(oldmode, "unknown", 10);	break;
     case OMrunning:	strlcpy(oldmode, "running", 10);	break;
     case OMpaused:	strlcpy(oldmode, "paused", 10);		break;
@@ -302,7 +316,7 @@ PY_addhist(PyObject *self UNUSED, PyObject *args)
     char	*msgid;
     Py_ssize_t  msgidlen;
     char	*articlepaths = (char *) "";
-    char	tbuff[12];
+    char	tbuff[32];
     char	*parambuf[6];
 
     if (!PyArg_ParseTuple(args, (char *) "s#", &msgid, &msgidlen))
@@ -512,7 +526,8 @@ PY_hashstring(PyObject *self UNUSED, PyObject *args)
 	/* Compress out multiple whitespace in the trimmed string.  We
 	 * do a copy because this is probably an original art
 	 * buffer. */
-	workstring =  memcpy(xmalloc(worksize), wpos, worksize);
+        workstring = xmalloc(worksize + 1);
+        memcpy(workstring, wpos, worksize);
         wasspace = false;
 	p = wpos;
 	q = workstring;
@@ -562,6 +577,36 @@ static PyMethodDef INNPyMethods[] = {
     METHOD(NULL,              NULL,               0,            "")
 };
 
+#if PY_MAJOR_VERSION >= 3
+static struct PyModuleDef INNPyModule = {
+    PyModuleDef_HEAD_INIT,                /* m_base */
+    (char *) "INN",                       /* m_name */
+    (char *) "innd Python filter hook",   /* m_doc */
+    -1,                                   /* m_size */
+    INNPyMethods,                         /* m_methods */
+    NULL,                                 /* m_slots */
+    NULL,                                 /* m_traverse */
+    NULL,                                 /* m_clear */
+    NULL,                                 /* m_free */
+};
+
+PyMODINIT_FUNC
+PyInit_INN(void) {
+    PyObject *module = PyModule_Create(&INNPyModule);
+
+    if (module == NULL)
+        syslog(L_ERROR, "failed to create innd python module");
+
+    return module;
+}
+#else
+void
+PyInit_INN(void) {
+    if (Py_InitModule3((char *) "INN", INNPyMethods,
+                       (char *) "innd Python filter hook") == NULL)
+        syslog(L_ERROR, "failed to initialize innd python module");
+}
+#endif
 
 
 /*
@@ -697,11 +742,14 @@ PYsetup(void)
     const ARTHEADER *hp;
     size_t hdrcount;
 
-    /* Add path for nnrpd module.  The environment variable PYTHONPATH
+    /* Add path for innd module.  The environment variable PYTHONPATH
      * does it; one can also append innconf->pathfilter to sys.path once
      * Python has been initialized. */
     setenv("PYTHONPATH", innconf->pathfilter, 1);
 
+    /* Build a module interface to certain INN functions. */
+    PyImport_AppendInittab("INN", &PyInit_INN);
+
     /* Load up the interpreter ;-O */
     Py_Initialize();
 
@@ -716,12 +764,10 @@ PYsetup(void)
 	return;
     }
 
-    /* Build a module interface to certain INN functions. */
-    Py_InitModule((char *) "INN", INNPyMethods);
-
     PYFilterModule = PyImport_ImportModule((char *) INN_PATH_PYTHON_STARTUP_M);
     if (PYFilterModule == NULL)
-	syslog(L_ERROR, "failed to import external python module");
+	syslog(L_ERROR, "failed to import external %s python module",
+           INN_PATH_PYTHON_STARTUP_M);
 
     if (PYFilterObject == NULL) {
 	syslog(L_ERROR, "python filter object is not defined");
@@ -740,10 +786,9 @@ PYsetup(void)
     PYheaditem = xmalloc((hdrcount + 2) * sizeof(PyObject *));
     PYheadkey = xmalloc(hdrcount * sizeof(PyObject *));
 
-    /* Preallocate keys for the article dictionary */
+    /* Preallocate keys for the article dictionary. */
     for (hp = ARTheaders; hp < ARRAY_END(ARTheaders); hp++)
 	PYheadkey[hp - ARTheaders] = PyString_InternFromString(hp->Name);
-    PYpathkey = PyString_InternFromString("Path");
     PYlineskey = PyString_InternFromString("__LINES__");
     PYbodykey = PyString_InternFromString("__BODY__");
 
