@@ -1,4 +1,4 @@
-/*  $Id: dbz.c 10119 2016-11-09 20:30:01Z iulius $
+/*  $Id: dbz.c 10283 2018-05-14 12:43:05Z iulius $
 **
 **  dbz database implementation V6.1.1
 **
@@ -283,7 +283,7 @@ static hash_table etab;         /* existance hash table, used for existance chec
 #endif
 static bool dirty;		/* has a store() been done? */
 static erec empty_rec;          /* empty rec to compare against
-				   initalized in dbzinit */
+				   initialized in dbzinit */
 
 /* misc. forwards */
 static bool getcore(hash_table *tab);
