@@ -1,4 +1,4 @@
-/* $Id: inet_aton.c 10099 2016-11-04 22:21:59Z iulius $
+/* $Id: inet_aton.c 10246 2018-02-16 21:12:42Z iulius $
  *
  * Replacement for a missing inet_aton.
  *
@@ -10,14 +10,16 @@
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
+ * Copyright 2000-2001, 2017 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2008, 2011, 2014
+ *     The Board of Trustees of the Leland Stanford Junior University
  *
- * The authors hereby relinquish any claim to any copyright that they may have
- * in this work, whether granted under contract or by operation of law or
- * international treaty, and hereby commit to the public, at large, that they
- * shall not, at any time in the future, seek to enforce any copyright in this
- * work against any person or entity, or prevent any person or entity from
- * copying, publishing, distributing or creating derivative works of this
- * work.
+ * Copying and distribution of this file, with or without modification, are
+ * permitted in any medium without royalty provided the copyright notice and
+ * this notice are preserved.  This file is offered as-is, without any
+ * warranty.
+ *
+ * SPDX-License-Identifier: FSFAP
  */
 
 #include "config.h"
@@ -37,7 +39,8 @@ int test_inet_aton(const char *, struct in_addr *);
 int
 inet_aton(const char *s, struct in_addr *addr)
 {
-    unsigned long octet[4], address;
+    unsigned octet[4];
+    uint32_t address;
     const char *p;
     int base, i;
     int part = 0;
