@@ -1,4 +1,4 @@
-/*  $Id: uwildmat.c 6779 2004-05-17 07:25:28Z rra $
+/*  $Id: uwildmat.c 10326 2019-02-04 14:22:34Z iulius $
 **
 **  wildmat pattern matching with Unicode UTF-8 extensions.
 **
@@ -44,7 +44,7 @@
 **  June, 1991:  Robert Elz <kre@munnari.oz.au> added minus and close bracket
 **  handling for character sets.
 **
-**  July, 2000:  Largely rewritten by Russ Allbery <rra@stanford.edu> to add
+**  July, 2000:  Largely rewritten by Russ Allbery <eagle@eyrie.org> to add
 **  support for ',', '!', and optionally '@' to the core wildmat routine.
 **  Broke the character class matching into a separate function for clarity
 **  since it's infrequently used in practice, and added some simple lookahead
@@ -52,7 +52,7 @@
 **  Added support for UTF-8 as the default character set for any high-bit
 **  characters.
 **
-**  For more information on UTF-8, see RFC 2279.
+**  For more information on UTF-8, see RFC 3629.
 **
 **  Please note that this file is intentionally written so that conditionally
 **  executed expressions are on separate lines from the condition to
@@ -63,7 +63,9 @@
 
 #include "config.h"
 #include "clibrary.h"
-#include "libinn.h"
+#include <ctype.h>
+
+#include "inn/libinn.h"
 
 #define ABORT -1
 
@@ -93,13 +95,61 @@ utf8_length(const unsigned char *start, const unsigned char *end)
     if (end != NULL && (end - start + 1) < length)
         return 1;
     left = length - 1;
-    p = start + 1;
     for (p = start + 1; left > 0 && (*p & 0xc0) == 0x80; p++)
         left--;
     return (left == 0) ? length : 1;
 }
 
 
+/*
+**  Check whether a string contains only valid UTF-8 characters, without
+**  any ASCII control characters except for \r, \n and \t.
+*/
+bool
+is_valid_utf8(const char *text)
+{
+    unsigned char mask;
+    const unsigned char *p;
+    int length;
+    int left;
+
+    for (p = (const unsigned char *)text; *p != '\0';) {
+        mask = 0x80;
+        length = 0;
+
+        /* Find out the expected length of the character. */
+        for (; mask > 0 && (*p & mask) == mask; mask >>= 1)
+            length++;
+
+        p++;
+
+        /* Valid printable ASCII character or CR, LF or HTAB. */
+        if (length == 0) {
+            if(isprint((unsigned char) p[-1])
+               || p[-1] == '\r' || p[-1] == '\n' || p[-1] == '\t') {
+                continue;
+            } else {
+                return false;
+            }
+        }
+
+        /* Invalid length. */
+        if (length < 2 || length > 6)
+            return false;
+
+        /* Check that each byte looks like 10xxxxxx, except for the first. */
+        left = length - 1;
+        for (; left > 0 && (*p & 0xc0) == 0x80; p++)
+            left--;
+
+        if (left > 0)
+            return false;
+    }
+
+    return true;
+}
+
+
 /*
 **  Convert a UTF-8 character to UCS-4.  Takes a pointer to the start of the
 **  character and to the last octet of the string, and to a uint32_t into
@@ -147,7 +197,8 @@ match_class(uint32_t text, const unsigned char *start,
 {
     bool reversed, allowrange;
     const unsigned char *p = start;
-    uint32_t first, last;
+    uint32_t first = 0;
+    uint32_t last;
 
     /* Check for an inverted character class (starting with ^).  If the
        character matches the character class, we return !reversed; that way,
@@ -234,7 +285,7 @@ match_pattern(const unsigned char *text, const unsigned char *start,
 
                Optimization: If the character after the * in the pattern
                isn't a metacharacter (the common case), then the * has to
-               consume characters at least up to the next occurance of that
+               consume characters at least up to the next occurrence of that
                character in the text.  Scan forward for those points rather
                than recursing at every possible point to save the extra
                function call overhead. */
@@ -285,11 +336,11 @@ match_pattern(const unsigned char *text, const unsigned char *start,
 
 /*
 **  Takes text and a wildmat expression; a wildmat expression is a
-**  comma-separated list of wildmat patterns, optionally preceeded by ! to
-**  invert the sense of the expression.  Returns WILDMAT_MATCH if that
-**  expression matches the text, WILDMAT_FAIL otherwise.  If allowpoison is
+**  comma-separated list of wildmat patterns, optionally preceded by ! to
+**  invert the sense of the expression.  Returns UWILDMAT_MATCH if that
+**  expression matches the text, UWILDMAT_FAIL otherwise.  If allowpoison is
 **  set, allow @ to introduce a poison expression (the same as !, but if it
-**  triggers the failed match the routine returns WILDMAT_POISON instead).
+**  triggers the failed match the routine returns UWILDMAT_POISON instead).
 */
 static enum uwildmat
 match_expression(const unsigned char *text, const unsigned char *start,
@@ -308,7 +359,7 @@ match_expression(const unsigned char *text, const unsigned char *start,
         return !*text ? UWILDMAT_MATCH : UWILDMAT_FAIL;
     end = start + strlen((const char *) start) - 1;
 
-    /* Main match loop.  Find each comma that separates patterns, and attempt 
+    /* Main match loop.  Find each comma that separates patterns, and attempt
        to match the text with each pattern in order.  The last matching
        pattern determines whether the whole expression matches. */
     for (; p <= end + 1; p = split + 1) {
