@@ -1,4 +1,4 @@
-/*  $Id: commands.c 9978 2015-12-11 20:39:56Z iulius $
+/*  $Id: commands.c 10149 2017-06-05 12:24:58Z iulius $
 **
 **  Miscellaneous commands.
 */
@@ -14,6 +14,7 @@
 #include "inn/version.h"
 #include "tls.h"
 
+extern bool laxmid;
 #if defined(HAVE_OPENSSL)
 extern bool encryption_layer_on;
 #endif /* HAVE_OPENSSL */
@@ -625,7 +626,7 @@ CMDpost(int ac, char *av[])
     ihave = (strcasecmp(av[0], "IHAVE") == 0);
 
     /* Check whether the message-ID is valid for IHAVE. */
-    if (ihave && ac == 2 && !IsValidMessageID(av[1], true)) {
+    if (ihave && ac == 2 && !IsValidMessageID(av[1], true, laxmid)) {
         Reply("%d Syntax error in message-ID\r\n", NNTP_ERR_SYNTAX);
         return;
     }
