@@ -1,4 +1,4 @@
-/*  $Id: misc.c 10078 2016-10-08 20:53:39Z iulius $
+/*  $Id: misc.c 10305 2018-12-02 14:21:56Z iulius $
 **
 **  Miscellaneous support routines.
 */
@@ -217,7 +217,7 @@ char *
 PostRecFilename(char *ip, char *user) 
 {
      static char                   buff[SPOOLNAMEBUFF];
-     char                          dirbuff[SPOOLNAMEBUFF];
+     char                          dirbuff[SMBUF+2+3*3];
      struct in_addr                inaddr;
      unsigned long int             addr;
      unsigned char                 quads[4];
@@ -491,7 +491,7 @@ IsValidAlgorithm(const char *string)
 
 #if defined(HAVE_ZLIB)
 /*
-**  The COMPRESS command.
+**  The COMPRESS command.  RFC 8054.
 */
 void
 CMDcompress(int ac, char *av[])
