@@ -1,4 +1,4 @@
-/*  $Id: perm.c 9847 2015-05-03 15:01:03Z iulius $
+/*  $Id: perm.c 10117 2016-11-06 14:23:27Z iulius $
 **
 **  How to figure out where a user comes from, and what that user can do once
 **  we know who sie is.
@@ -15,15 +15,16 @@
 #include "inn/innconf.h"
 #include "innperl.h"
 #include "nnrpd.h"
+#include "tls.h"
 
 /* Needed on AIX 4.1 to get fd_set and friends. */
 #ifdef HAVE_SYS_SELECT_H
 # include <sys/select.h>
 #endif
 
-#ifdef HAVE_OPENSSL
-extern bool nnrpd_starttls_done;
-#endif /* HAVE_OPENSSL */
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
+extern bool encryption_layer_on;
+#endif /* HAVE_OPENSSL || HAVE_SASL */
 
 /* Data types. */
 typedef struct _CONFCHAIN {
@@ -42,7 +43,7 @@ typedef struct _METHOD {
 typedef struct _AUTHGROUP {
     char *name;
     char *key;
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
     int require_ssl;
 #endif
     char *hosts;
@@ -161,7 +162,7 @@ extern bool PerlLoaded;
 #define PERMperl_access         59
 #define PERMpython_access       60
 #define PERMpython_dynamic      61
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
 #define PERMrequire_ssl         62
 #define PERMMAX                 63
 #else
@@ -251,7 +252,7 @@ static CONFTOKEN PERMtoks[] = {
     { PERMperl_access,          (char *) "perl_access:"         },
     { PERMpython_access,        (char *) "python_access:"       },
     { PERMpython_dynamic,       (char *) "python_dynamic:"      },
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
     { PERMrequire_ssl,          (char *) "require_ssl:"         },
 #endif
     { 0,                        (char *) NULL                   }
@@ -351,7 +352,7 @@ copy_authgroup(AUTHGROUP *orig)
     else
 	ret->hosts = 0;
 
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
     ret->require_ssl = orig->require_ssl;
 #endif
 
@@ -453,7 +454,7 @@ copy_accessgroup(ACCESSGROUP *orig)
 static void
 SetDefaultAuth(AUTHGROUP *curauth UNUSED)
 {
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
         curauth->require_ssl = false;
 #endif
 }
@@ -633,7 +634,7 @@ static void
 authdecl_parse(AUTHGROUP *curauth, CONFFILE *f, CONFTOKEN *tok)
 {
     int oldtype;
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
     int boolval;
 #endif
     METHOD *m;
@@ -655,7 +656,7 @@ authdecl_parse(AUTHGROUP *curauth, CONFFILE *f, CONFTOKEN *tok)
 	ReportError(f, buff);
     }
 
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
     if (strcasecmp(tok->name, "on") == 0
         || strcasecmp(tok->name, "true") == 0
         || strcasecmp(tok->name, "yes") == 0)
@@ -673,7 +674,7 @@ authdecl_parse(AUTHGROUP *curauth, CONFFILE *f, CONFTOKEN *tok)
 	curauth->key = xstrdup(tok->name);
 	SET_CONFIG(PERMkey);
 	break;
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
       case PERMrequire_ssl:
         if (boolval != -1)
             curauth->require_ssl = boolval;
@@ -1266,7 +1267,7 @@ PERMreadfile(char *filename)
 
 		/* Stuff that belongs to an auth group. */
 	      case PERMhost:
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
               case PERMrequire_ssl:
 #endif
 	      case PERMauthprog:
@@ -1402,10 +1403,9 @@ again:
 }
 
 void
-PERMgetaccess(char *nnrpaccess)
+PERMgetinitialaccess(char *readersconf)
 {
     int i;
-    char *uname;
 
     auth_realms	    = NULL;
     access_realms   = NULL;
@@ -1416,24 +1416,28 @@ PERMgetaccess(char *nnrpaccess)
 #else
     PERMcanauthenticate = false;
 #endif
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
     PERMcanauthenticatewithoutSSL = false;
 #endif
     PERMgroupmadeinvalid = false;
     PERMcanpostgreeting = false;
     PERMcanread	    = PERMcanpost   = false;
-    PERMreadlist    = PERMpostlist  = false;
+    PERMreadlist    = PERMpostlist  = NULL;
     PERMaccessconf = NULL;
 
     if (ConfigBit == NULL) {
-	if (PERMMAX % 8 == 0)
-	    ConfigBitsize = PERMMAX/8;
-	else
-	    ConfigBitsize = (PERMMAX - (PERMMAX % 8))/8 + 1;
-	ConfigBit = xcalloc(ConfigBitsize, 1);
+        if (PERMMAX % 8 == 0) {
+            ConfigBitsize = PERMMAX/8;
+        } else {
+            ConfigBitsize = (PERMMAX - (PERMMAX % 8))/8 + 1;
+        }
+        ConfigBit = xcalloc(ConfigBitsize, 1);
     }
-    PERMreadfile(nnrpaccess);
 
+    /* Parse the readers.conf file. */
+    PERMreadfile(readersconf);
+
+    /* Remove unused access groups. */
     strip_accessgroups();
 
     if (auth_realms == NULL) {
@@ -1445,12 +1449,12 @@ PERMgetaccess(char *nnrpaccess)
     }
 
     /* auth_realms are all expected to match the user.
-     * Be careful whether SSL is required, though. */
-    for (i = 0; auth_realms[i]; i++) {
+     * Be careful whether an encryption layer is required, though. */
+    for (i = 0; auth_realms[i] != NULL; i++) {
 	if (auth_realms[i]->auth_methods != NULL) {
 	    PERMcanauthenticate = true;
-#ifdef HAVE_OPENSSL
-            if (auth_realms[i]->require_ssl == false)
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
+            if (!auth_realms[i]->require_ssl)
                 PERMcanauthenticatewithoutSSL = true;
 #endif
         }
@@ -1461,54 +1465,89 @@ PERMgetaccess(char *nnrpaccess)
             || auth_realms[i]->dynamic_script != NULL)
             PERMcanpostgreeting = true;
     }
-    uname = 0;
-    while (!uname && i--) {
-#ifdef HAVE_OPENSSL
-        /* If SSL is required, check that the connection is encrypted. */
-        if ((auth_realms[i]->require_ssl == true) && !nnrpd_starttls_done)
+}
+
+void
+PERMgetaccess(bool initialconnection)
+{
+    char *uname;
+    int i;
+
+    if (ConfigBit == NULL) {
+        if (PERMMAX % 8 == 0) {
+            ConfigBitsize = PERMMAX/8;
+        } else {
+            ConfigBitsize = (PERMMAX - (PERMMAX % 8))/8 + 1;
+        }
+        ConfigBit = xcalloc(ConfigBitsize, 1);
+    }
+
+    if (auth_realms == NULL) {
+        return;
+    }
+
+    for (i = 0; auth_realms[i] != NULL; i++) {
+            ;
+    }
+
+    uname = NULL;
+    while (uname == NULL && i-- > 0) {
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
+        /* If an encryption layer is required, check that the connection
+         * really uses one. */
+        if (auth_realms[i]->require_ssl && !encryption_layer_on) {
             continue;
+        }
 #endif
-	if ((uname = ResolveUser(auth_realms[i])) != NULL)
-	    PERMauthorized = true;
-	if (!uname && auth_realms[i]->default_user)
-	    uname = xstrdup(auth_realms[i]->default_user);
+        if ((uname = ResolveUser(auth_realms[i])) != NULL) {
+            PERMauthorized = true;
+        }
+        if (uname == NULL && auth_realms[i]->default_user != NULL) {
+            uname = xstrdup(auth_realms[i]->default_user);
+        }
     }
-    if (uname) {
-	strlcpy(PERMuser, uname, sizeof(PERMuser));
+    if (uname != NULL) {
+        strlcpy(PERMuser, uname, sizeof(PERMuser));
         free(uname);
-	uname = strchr(PERMuser, '@');
-	if (!uname && auth_realms[i]->default_domain) {
-	    /* Append the default domain to the username. */
-	    strlcat(PERMuser, "@", sizeof(PERMuser));
-	    strlcat(PERMuser, auth_realms[i]->default_domain,
+        uname = strchr(PERMuser, '@');
+        if (uname == NULL && auth_realms[i]->default_domain != NULL) {
+            /* Append the default domain to the username. */
+            strlcat(PERMuser, "@", sizeof(PERMuser));
+            strlcat(PERMuser, auth_realms[i]->default_domain,
                     sizeof(PERMuser));
-	}
-	PERMneedauth = false;
-	success_auth = auth_realms[i];
-	syslog(L_TRACE, "%s res %s", Client.host, PERMuser);
-    } else if (!PERMcanauthenticate) {
-	/* Couldn't resolve the user. */
-	syslog(L_NOTICE, "%s no_user", Client.host);
-	Reply("%d Could not get your access name.  Goodbye!\r\n",
-	  NNTP_ERR_ACCESS);
-	ExitWithStats(1, true);
+        }
+        PERMneedauth = false;
+        success_auth = auth_realms[i];
+        syslog(L_TRACE, "%s res %s", Client.host, PERMuser);
+    } else if (initialconnection && !PERMcanauthenticate) {
+        /* Couldn't resolve the user. */
+        syslog(L_NOTICE, "%s no_user", Client.host);
+        Reply("%d Could not get your access name.  Goodbye!\r\n",
+              NNTP_ERR_ACCESS);
+        ExitWithStats(1, true);
     } else {
-	PERMneedauth = true;
+        PERMneedauth = true;
     }
-    /* Check maximum allowed permissions for any host that matches (for
-     * the greeting string). */
-    for (i = 0; access_realms[i]; i++) {
-	if (!PERMcanread)
-	    PERMcanread = (access_realms[i]->read != NULL);
-	if (!PERMcanpost)
-	    PERMcanpost = (access_realms[i]->post != NULL);
-        if (!PERMcanpostgreeting)
-            PERMcanpostgreeting = (access_realms[i]->post != NULL);
-    }
-    if (!i) {
-	/* No applicable access groups.  Zeroing all these makes INN
-	 * return permission denied to client. */
-	PERMcanread = PERMcanpost = PERMneedauth = false;
+
+    if (initialconnection) {
+        /* Check maximum allowed permissions for any host that matches (for
+         * the greeting string). */
+        for (i = 0; access_realms[i] != NULL; i++) {
+            if (!PERMcanread) {
+                PERMcanread = (access_realms[i]->read != NULL);
+            }
+            if (!PERMcanpost) {
+                PERMcanpost = (access_realms[i]->post != NULL);
+            }
+            if (!PERMcanpostgreeting) {
+                PERMcanpostgreeting = (access_realms[i]->post != NULL);
+            }
+        }
+        if (i == 0) {
+            /* No applicable access groups.  Zeroing all these makes INN
+             * return permission denied to client. */
+            PERMcanread = PERMcanpost = PERMneedauth = false;
+        }
     }
 }
 
@@ -1953,9 +1992,10 @@ ResolveUser(AUTHGROUP *auth)
     if (auth->res_methods == NULL)
         return NULL;
 
-#ifdef HAVE_OPENSSL
-    /* If SSL is required, check that the connection is encrypted. */
-    if ((auth->require_ssl == true) && !nnrpd_starttls_done)
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
+    /* If an encryption layer is required, check that the connection
+     * really uses one. */
+    if (auth->require_ssl && !encryption_layer_on)
         return NULL;
 #endif
 
@@ -2003,9 +2043,10 @@ AuthenticateUser(AUTHGROUP *auth, char *username, char *password,
     if (auth->auth_methods == NULL)
         return NULL;
 
-#ifdef HAVE_OPENSSL
-    /* If SSL is required, check that the connection is encrypted. */
-    if ((auth->require_ssl == true) && !nnrpd_starttls_done)
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
+    /* If an encryption layer is required, check that the connection
+     * really uses one. */
+    if (auth->require_ssl && !encryption_layer_on)
         return NULL;
 #endif
 
