@@ -1,17 +1,10 @@
-/*  $Id: tls.c 10090 2016-11-03 02:30:12Z eagle $
+/*  $Id: tls.c 10309 2018-12-02 14:35:10Z iulius $
 **
-**  tls.c -- TLSv1 functions.
+**  tls.c -- TLS functions.
 **  Copyright (C) 2000 Kenichi Okada <okada@opaopa.org>.
 **
 **  Author:  Kenichi Okada <okada@opaopa.org>
 **  Created:  2000-02-22
-**
-**  [RFC 2246] "The TLS Protocol Version 1.0"
-**      by Christopher Allen <callen@certicom.com> and
-**      Tim Dierks <tdierks@certicom.com> (1999/01)
-**
-**  [RFC 2595] "Using TLS with IMAP, POP3 and ACAP"
-**      by Chris Newman <chris.newman@innosoft.com> (1999/06)
 */
 
 #include "config.h"
@@ -81,20 +74,20 @@ apps_ssl_info_callback(const SSL *s, int where, int ret)
 
     if (where & SSL_CB_LOOP) {
 	if (tls_serverengine && (tls_loglevel >= 2))
-	    Printf("%s:%s", str, SSL_state_string_long(s));
+            syslog(L_NOTICE, "%s:%s", str, SSL_state_string_long(s));
     } else if (where & SSL_CB_ALERT) {
 	str = (where & SSL_CB_READ) ? "read" : "write";
 	if ((tls_serverengine && (tls_loglevel >= 2)) ||
 	    ((ret & 0xff) != SSL3_AD_CLOSE_NOTIFY))
-	  Printf("SSL3 alert %s:%s:%s", str,
+            syslog(L_NOTICE, "SSL3 alert %s:%s:%s", str,
 		 SSL_alert_type_string_long(ret),
 		 SSL_alert_desc_string_long(ret));
     } else if (where & SSL_CB_EXIT) {
 	if (ret == 0)
-	    Printf("%s:failed in %s",
+            syslog(L_ERROR, "%s:failed in %s",
 		     str, SSL_state_string_long(s));
 	else if (ret < 0) {
-	    Printf("%s:error in %s",
+            syslog(L_ERROR, "%s:error in %s",
 		     str, SSL_state_string_long(s));
 	}
     }
@@ -244,10 +237,12 @@ verify_callback(int ok, X509_STORE_CTX * ctx)
     err = X509_STORE_CTX_get_error(ctx);
     depth = X509_STORE_CTX_get_error_depth(ctx);
 
-    if (err_cert != NULL) {
-        X509_NAME_oneline(X509_get_subject_name(err_cert), buf, sizeof(buf));
-        if ((tls_serveractive) && (tls_loglevel >= 1)) {
-            Printf("Peer cert verify depth=%d %s", depth, buf);
+    if ((tls_serveractive) && (tls_loglevel >= 1)) {
+        if (err_cert != NULL) {
+            X509_NAME_oneline(X509_get_subject_name(err_cert), buf, sizeof(buf));
+            syslog(L_NOTICE, "Peer cert verify depth=%d %s", depth, buf);
+        } else {
+            syslog(L_NOTICE, "Peer cert verify depth=%d <no cert>", depth);
         }
     }
     
@@ -280,7 +275,7 @@ verify_callback(int ok, X509_STORE_CTX * ctx)
 	break;
     }
     if ((tls_serveractive) && (tls_loglevel >= 1))
-      Printf("verify return:%d", ok);
+        syslog(L_NOTICE, "verify return:%d", ok);
 
     return (ok);
 }
@@ -348,14 +343,14 @@ tls_dump(const char *s, int len)
 	/* If this is the last call, then update the ddt_dump thing so that
          * we will move the selection point in the debug window. */
 	if (tls_loglevel>0)
-	  Printf("%s", buf);
+            syslog(L_NOTICE, "%s", buf);
 	ret += strlen(buf);
     }
 #ifdef TRUNCATE
     if (trunc > 0) {
 	snprintf(buf, sizeof(buf), "%04x - <SPACES/NULS>\n", len+ trunc);
 	if (tls_loglevel>0)
-	  Printf("%s", buf);
+            syslog(L_NOTICE, "%s", buf);
 	ret += strlen(buf);
     }
 #endif
@@ -477,7 +472,8 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
                       char *tls_CAfile, char *tls_CApath, char *tls_cert_file,
                       char *tls_key_file, bool prefer_server_ciphers,
                       bool tls_compression, struct vector *tls_proto_vect,
-                      char *tls_ciphers, char *tls_ec_curve UNUSED)
+                      char *tls_ciphers, char *tls_ciphers13 UNUSED,
+                      char *tls_ec_curve UNUSED)
 {
     int     off = 0;
     int     verify_flags = SSL_VERIFY_NONE;
@@ -496,7 +492,7 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
       return (0);				/* Already running. */
 
     if (tls_loglevel >= 2)
-      Printf("starting TLS engine");
+      syslog(L_NOTICE, "starting TLS engine");
 
 /* New functions have been introduced in OpenSSL 1.1.0. */
 #if OPENSSL_VERSION_NUMBER < 0x010100000L
@@ -530,7 +526,7 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
     if ((!SSL_CTX_load_verify_locations(CTX, CAfile, CApath)) ||
 	(!SSL_CTX_set_default_verify_paths(CTX))) {
       if (tls_loglevel >= 2)
-	Printf("TLS engine: cannot load CA data\n");
+          syslog(L_ERROR, "TLS engine: cannot load CA data");
       return (-1);
     }
     
@@ -545,7 +541,7 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
     
     if (!set_cert_stuff(CTX, s_cert_file, s_key_file)) {
       if (tls_loglevel >= 2)
-	Printf("TLS engine: cannot load cert/key data\n");
+          syslog(L_ERROR, "TLS engine: cannot load cert/key data");
       return (-1);
     }
 
@@ -567,12 +563,17 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
     if (eckey != NULL) {
         SSL_CTX_set_tmp_ecdh(CTX, eckey);
     } else {
-# ifdef SSL_CTX_set_ecdh_auto
+# if OPENSSL_VERSION_NUMBER < 0x010100000L
+#  if OPENSSL_VERSION_NUMBER >= 0x01000200fL
+        /* Function supported since OpenSSL 1.0.2.
+         * Removed since OpenSSL 1.1.0, supporting ECDH by default with
+         * the most appropriate parameters. */
         SSL_CTX_set_ecdh_auto(CTX, 1);
-# else
+#  else
         SSL_CTX_set_tmp_ecdh(CTX,
                              EC_KEY_new_by_curve_name(NID_X9_62_prime256v1));
-# endif /* SSL_CTX_set_ecdh_auto */
+#  endif /* SSL_CTX_set_ecdh_auto */
+# endif /* OpenSSL version < 1.1.0 */
      }
 #endif /* HAVE_OPENSSL_ECC */
 
@@ -600,6 +601,8 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
                     tls_protos |= INN_TLS_TLSv1_1;
                 } else if (strcmp(tls_proto_vect->strings[i], "TLSv1.2") == 0) {
                     tls_protos |= INN_TLS_TLSv1_2;
+                } else if (strcmp(tls_proto_vect->strings[i], "TLSv1.3") == 0) {
+                    tls_protos |= INN_TLS_TLSv1_3;
                 } else {
                     syslog(L_ERROR, "TLS engine: unknown protocol '%s' in tlsprotocols",
                            tls_proto_vect->strings[i]);
@@ -608,7 +611,8 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
         }
     } else {
         /* Default value:  allow only TLS protocols. */
-        tls_protos = (INN_TLS_TLSv1 | INN_TLS_TLSv1_1 | INN_TLS_TLSv1_2);
+        tls_protos = (INN_TLS_TLSv1 | INN_TLS_TLSv1_1 | INN_TLS_TLSv1_2
+                      | INN_TLS_TLSv1_3);
     }
 
     if ((tls_protos & INN_TLS_SSLv2) == 0) {
@@ -635,6 +639,12 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
 #endif
     }
 
+    if ((tls_protos & INN_TLS_TLSv1_3) == 0) {
+#ifdef SSL_OP_NO_TLSv1_3
+        SSL_CTX_set_options(CTX, SSL_OP_NO_TLSv1_3);
+#endif
+    }
+
     if (tls_ciphers != NULL) {
         if (SSL_CTX_set_cipher_list(CTX, tls_ciphers) == 0) {
             syslog(L_ERROR, "TLS engine: cannot set cipher list");
@@ -642,6 +652,16 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
         }
     }
 
+#if OPENSSL_VERSION_NUMBER >= 0x01010100fL
+    /* New API added in OpenSSL 1.1.1 for TLSv1.3 cipher suites. */
+    if (tls_ciphers13 != NULL) {
+        if (SSL_CTX_set_ciphersuites(CTX, tls_ciphers13) == 0) {
+            syslog(L_ERROR, "TLS engine: cannot set ciphersuites");
+            return (-1);
+        }
+    }
+#endif
+
     if (tls_compression) {
 #if defined(SSL_OP_NO_COMPRESSION) && OPENSSL_VERSION_NUMBER >= 0x0009080dfL
         /* Function first added in OpenSSL 0.9.8m. */
@@ -698,6 +718,7 @@ tls_init(void)
                                        innconf->tlscompression,
                                        innconf->tlsprotocols,
                                        innconf->tlsciphers,
+                                       innconf->tlsciphers13,
                                        innconf->tlseccurve);
 
     if (ssl_result == -1) {
@@ -728,15 +749,15 @@ bio_dump_cb(BIO * bio, int cmd, const char *argp, int argi, long argl UNUSED,
 	return (ret);
 
     if (cmd == (BIO_CB_READ | BIO_CB_RETURN)) {
-        Printf("read from %08lX [%08lX] (%d bytes => %ld (0x%X))",
+        syslog(L_NOTICE, "read from %08lX [%08lX] (%d bytes => %ld (0x%lX))",
                (unsigned long) bio, (unsigned long) argp,
-               argi, ret, (unsigned int) ret);
+               argi, ret, (unsigned long) ret);
 	tls_dump(argp, (int) ret);
 	return (ret);
     } else if (cmd == (BIO_CB_WRITE | BIO_CB_RETURN)) {
-        Printf("write to %08lX [%08lX] (%d bytes => %ld (0x%X))",
+        syslog(L_NOTICE, "write to %08lX [%08lX] (%d bytes => %ld (0x%lX))",
                (unsigned long) bio, (unsigned long) argp,
-               argi, ret, (unsigned int) ret);
+               argi, ret, (unsigned long) ret);
 	tls_dump(argp, (int) ret);
     }
     return (ret);
@@ -767,7 +788,7 @@ tls_start_servertls(int readfd, int writefd)
       return (-1);
     }
     if (tls_loglevel >= 1)
-	Printf("setting up TLS connection");
+	syslog(L_NOTICE, "setting up TLS connection");
 
     if (tls_conn == NULL)
     {
