@@ -1,22 +1,12 @@
-/*  $Id: tls.h 10067 2016-09-04 13:11:52Z iulius $
+/*  $Id: tls.h 10309 2018-12-02 14:35:10Z iulius $
 **
-**  tls.h -- TLSv1 functions.
+**  tls.h -- TLS functions.
 **  Copyright (C) 2000 Kenichi Okada <okada@opaopa.org>.
 **
 **  Author:  Kenichi Okada <okada@opaopa.org>
 **  Created:  2000-02-22
-**
-**  [RFC 2246] "The TLS Protocol Version 1.0"
-**      by Christopher Allen <callen@certicom.com> and
-**      Tim Dierks <tdierks@certicom.com> (1999/01)
-**
-**  [RFC 2595] "Using TLS with IMAP, POP3 and ACAP"
-**      by Chris Newman <chris.newman@innosoft.com> (1999/06)
 */
 
-#ifndef HAVE_OPENSSL_SSL_H
-# undef HAVE_OPENSSL
-#endif
 #ifdef HAVE_OPENSSL
 
 #ifndef TLS_H
@@ -49,6 +39,7 @@
 #define INN_TLS_TLSv1 4
 #define INN_TLS_TLSv1_1 8
 #define INN_TLS_TLSv1_2 16
+#define INN_TLS_TLSv1_3 32
 
 /* Init TLS engine. */
 int tls_init_serverengine(int verifydepth, /* Depth to verify. */
@@ -62,6 +53,7 @@ int tls_init_serverengine(int verifydepth, /* Depth to verify. */
                           bool tls_compression,
                           struct vector *tls_protocols,
                           char *tls_ciphers,
+                          char *tls_ciphers13,
                           char *tls_ec_curve);
 
 /* Init TLS. */
