@@ -1,7 +1,7 @@
 ##########################################################################
 # INN module for innreport (3.*).
 #
-# $Id: innreport_inn.pm 9275 2011-07-17 19:09:26Z iulius $
+# $Id: innreport_inn.pm 10320 2018-12-29 13:46:28Z iulius $
 #
 # Sample file tested with INN 2.5, 2.4, 2.3, 2.2, 1.7.2 and 1.5.1.
 #
@@ -28,7 +28,7 @@ my %ctlinnd = ('a', 'addhist',     'D', 'allow',
 	       'i', 'hangup',      's', 'mode',
 	       'j', 'name',        'k', 'newgroup',
 	       'l', 'param',       'm', 'pause',
-	       'v', 'readers',     't', 'refile',
+	       'v', 'readers',     'H', 'stathist',
 	       'C', 'reject',      'o', 'reload',
 	       'n', 'renumber',    'z', 'reserve',
 	       'p', 'rmgroup',     'A', 'send',
@@ -36,7 +36,9 @@ my %ctlinnd = ('a', 'addhist',     'D', 'allow',
 	       'r', 'throttle',    'w', 'trace',
 	       'x', 'xabort',      'y', 'xexec',
 	       'E', 'logmode',     'F', 'feedinfo',
-	       'T', 'filter',      'P', 'perl',);
+	       'S', 'status',      'P', 'perl',
+               'L', 'lowmark',     'Y', 'python',
+               'Z', 'timer');
 
 my %timer_names = (idle     => 'idle',
                    hishave  => 'history lookup',
@@ -422,8 +424,8 @@ sub collect($$$$$$) {
       $inn_badart{$server}++;
       return 1;
     }
-    # 437 article includes "....."
-    if ($left =~ /(\S+) <[^>]+> (?:437|439) article includes/o) {
+    # Article accepted but includes "....."
+    if ($left =~ /(\S+) <[^>]+> Article accepted but includes/o) {
       my $server = $1;
       $server = lc $server unless $CASE_SENSITIVE;
       $innd_strange_strings{$server}++;
@@ -781,6 +783,8 @@ sub collect($$$$$$) {
       $innd_control{"shutdown"}++;
       return 1;
     }
+    # re-executed
+    return 1 if $left =~ m/^SERVER execv /o;
     # SERVER servermode paused
     return 1 if ($left =~ /(\S+) servermode paused$/o);
     # SERVER servermode running
@@ -1066,7 +1070,7 @@ sub collect($$$$$$) {
     return 1 if $left =~ m/ hostChkCxn - now/o;
     # loading path_to_config_file/innfeed.conf
     return 1 if $left =~ m/loading /o;
-    # Finnaly, to avoid problems with strange error lines, ignore them.
+    # Finally, to avoid problems with strange error lines, ignore them.
     #return 1 if ($left =~ /ME /);
   }
   ########
@@ -1499,6 +1503,13 @@ sub collect($$$$$$) {
     return 1 if $left =~ /^python: dynamic access module successfully hooked into nnrpd$/o;
     return 1 if $left =~ /^python: dynamic authorization access for read access granted$/o;
     return 1 if $left =~ /^python: dynamic authorization access type is not known: /o;
+    # during scanlogs
+    return 1 if $left =~ /^\S+ rejected Flushing log and syslog files$/o;
+    return 1 if $left =~ /^\S+ rejected Snapshot log and syslog files$/o;
+    # other logs that should not be reported as errors
+    return 1 if $left =~ /^\S+ auth also-log: /o;
+    return 1 if $left =~ /^\S+ res also-log: /o;
+    return 1 if $left =~ /^\S+ rejected by rule /o;
     # connect
     if ($left =~ /(\S+) (\([0-9a-fA-F:.]*\) )?connect(?: - port \d+)?$/o) {
       my $cust = $1;
@@ -1694,12 +1705,13 @@ sub collect($$$$$$) {
     }
     # can't getpeername
     if ($left =~ /\? can\'t getpeername/o) {
-      # $nnrpd_getpeername++;
       $nnrpd_gethostbyaddr{"? (can't getpeername)"}++;
       return 1;
     }
     # can't getsockname
     return 1 if $left =~ /^\S+ can\'t getsockname$/o;
+    # can't initialize TLS session
+    return 1 if $left =~ /^\S+ failure to negotiate TLS session$/o;
     # reverse lookup failed
     return 1 if $left =~ /^\? reverse lookup for \S+ failed: .* -- using IP address for access$/o;
     # profile timer
@@ -1930,6 +1942,7 @@ sub collect($$$$$$) {
     if ($left =~ /Article <[^>]*>: (.*) \(ID [[:xdigit:]]*\) not in keyring/o) {
       $nocem_badsigs{$1}++;
       $nocem_goodsigs{$1} = 0 unless ($nocem_goodsigs{$1});
+      $nocem_totalids{$1} = 0 unless ($nocem_totalids{$1});
       $nocem_totalbad++;
       $nocem_lastid = $1;
       return 1;
@@ -1937,6 +1950,7 @@ sub collect($$$$$$) {
     if ($left =~ /Article <[^>]*>: bad signature from (.*)/o) {
       $nocem_badsigs{$1}++;
       $nocem_goodsigs{$1} = 0 unless ($nocem_goodsigs{$1});
+      $nocem_totalids{$1} = 0 unless ($nocem_totalids{$1});
       $nocem_totalbad++;
       $nocem_lastid = $1;
       return 1;
@@ -1944,6 +1958,7 @@ sub collect($$$$$$) {
     if ($left =~ /Article <[^>]*>: malformed signature/o) {
       $nocem_badsigs{'N/A'}++;
       $nocem_goodsigs{'N/A'} = 0 unless ($nocem_goodsigs{'N/A'});
+      $nocem_totalids{'N/A'} = 0 unless ($nocem_totalids{'N/A'});
       $nocem_totalbad++;
       $nocem_lastid = 'N/A';
       return 1;
