@@ -1,4 +1,4 @@
-/*  $Id: cnfs.c 9873 2015-05-23 11:35:34Z iulius $
+/*  $Id: cnfs.c 10305 2018-12-02 14:21:56Z iulius $
 **
 **  Storage manager module for Cyclic News File System method.
 */
@@ -87,7 +87,8 @@ cnfs_explaintoken(const TOKEN token)
     uint32_t            block;
     uint32_t            cycnum;
 
-    snprintf(cycbuffname, sizeof(cycbuffname), "%s", token.token);
+    snprintf(cycbuffname, sizeof(cycbuffname), "%.*s",
+             (int) sizeof(cycbuffname)-1, token.token);
 
     if ((cycbuff = CNFSgetcycbuffbyname(cycbuffname)) == NULL) {
         blksz = CNFS_DFL_BLOCKSIZE;
@@ -837,7 +838,7 @@ static bool CNFSread_config(void) {
     for (ctab_i = 0; ctab_i < ctab_free; ctab_i++) {
 	if (strncmp(ctab[ctab_i], "cycbuff:", 8) == 0) {
 	    if (metacycbufffound) {
-                warn("CNFS: all cycbuff entries shoud be before metacycbuff"
+                warn("CNFS: all cycbuff entries should be before metacycbuff"
                      " entries");
 		free(config);
 		free(ctab);
@@ -1388,7 +1389,7 @@ ARTHANDLE *cnfs_retrieve(const TOKEN token, const RETRTYPE amount) {
 	*(CNFSARTHEADER *)&cahh = cah;
 	if(pread(cycbuff->fd, ((char *)&cahh)+sizeof(CNFSARTHEADER), sizeof(oldCNFSARTHEADER)-sizeof(CNFSARTHEADER), offset+sizeof(cah)) != sizeof(oldCNFSARTHEADER)-sizeof(CNFSARTHEADER)) {
             SMseterror(SMERR_UNDEFINED, "read2 failed");
-            syswarn("CNFS: could not read2 token %s %s:0x%s:%ld: %m",
+            syswarn("CNFS: could not read2 token %s %s:0x%s:%u: %m",
                     TokenToText(token), cycbuffname,
                     CNFSofft2hex(offset, false), cycnum);
             free(art);
