@@ -1,4 +1,5 @@
-/*
+/* $Id: ovdb.c 10306 2018-12-02 14:26:13Z iulius $
+ *
  * ovdb.c
  * ovdb 2.00
  * Overview storage using Berkeley DB 4.4 or higher
@@ -73,7 +74,6 @@
 #include "config.h"
 #include "clibrary.h"
 #include "portable/socket.h"
-#include "portable/time.h"
 #include <errno.h>
 #include <fcntl.h>
 #ifdef HAVE_LIMITS_H
@@ -89,7 +89,13 @@
 # define COMPRESS_MIN 600
 #endif
 
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
+#endif
+#include <time.h>
+
 #include "conffile.h"
+#include "inn/fdflag.h"
 #include "inn/innconf.h"
 #include "inn/libinn.h"
 #include "inn/messages.h"
@@ -97,16 +103,15 @@
 #include "inn/paths.h"
 #include "inn/storage.h"
 
+#ifdef HAVE_UNIX_DOMAIN_SOCKETS
+# include "portable/socket-unix.h"
+#endif
+
 #include "inn/ov.h"
 #include "ovinterface.h"
 #include "ovdb.h"
 #include "ovdb-private.h"
-
-#ifdef HAVE_UNIX_DOMAIN_SOCKETS
-# include <sys/un.h>
-#endif
-
-#ifndef USE_BERKELEY_DB
+#ifndef HAVE_BDB
 
 /* Provide stub functions if we don't have db */
 
@@ -150,7 +155,7 @@ bool ovdb_ctl(OVCTLTYPE type UNUSED, void *val UNUSED)
 
 void ovdb_close(void) { }
 
-#else /* USE_BERKELEY_DB */
+#else /* HAVE_BDB */
 
 #define EXPIREGROUP_TXN_SIZE 100
 #define DELETE_TXN_SIZE 500
@@ -209,7 +214,7 @@ static CONFTOKEN toks[] = {
 
 static int clientfd = -1;
 
-/* read client send and recieve functions. */
+/* read client send and receive functions. */
 
 static int
 csend(const void *data, int n)
@@ -406,7 +411,7 @@ void read_ovdb_conf(void)
     ovdb_conf.minkey = 0;
     ovdb_conf.maxlocks = 4000;
     ovdb_conf.nocompact = 1;
-    ovdb_conf.readserver = 0;
+    ovdb_conf.readserver = 1;
     ovdb_conf.numrsprocs = 5;
     ovdb_conf.maxrsconn = 0;
     ovdb_conf.useshm = 0;
@@ -592,7 +597,7 @@ static u_int32_t _db_flags = 0;
 static int open_db_file(int which)
 {
     int ret;
-    char name[10];
+    char name[16];
     DB_TXN *tid;
 
     if(dbs[which] != NULL)
@@ -931,6 +936,7 @@ mk_temp_groupinfo(int whichdb, group_id_t gno, DB_TXN *tid)
         break;
     default:
         warn("OVDB: mk_temp_groupinfo: groupinfo->put: %s", db_strerror(ret));
+        /* fallthrough */
     case TRYAGAIN:
         return ret;
     }
@@ -1265,7 +1271,7 @@ bool ovdb_getlock(int mode)
                      " running");
 	    return false;
 	}
-	close_on_exec(lockfd, true);
+	fdflag_close_exec(lockfd, true);
 	free(lockfn);
     } else
 	return true;
@@ -2599,6 +2605,7 @@ ovdb_expiregroup(const char *group, int *lo, struct history *h)
     default:
         warn("OVDB: expiregroup: ovdb_getgroupinfo failed: %s",
              db_strerror(ret));
+        /* fallthrough */
     case DB_NOTFOUND:
 	TXN_ABORT(t_expgroup_1, tid);
 	return false;
@@ -3056,4 +3063,4 @@ void ovdb_close(void)
     ovdb_releaselock();
 }
 
-#endif /* USE_BERKELEY_DB */
+#endif /* HAVE_BDB */
