@@ -1,4 +1,4 @@
-/* $Id: hashtab-t.c 9669 2014-09-03 17:18:22Z iulius $ */
+/* $Id: hashtab-t.c 10015 2016-05-05 12:43:09Z iulius $ */
 /* Test suite for lib/hashtab.c. */
 
 #include "config.h"
@@ -165,8 +165,10 @@ main(void)
     }
     ok(37, !reported);
 
-    if (fseek(words, 0, SEEK_SET) < 0)
+    if (fseek(words, 0, SEEK_SET) < 0) {
+        fclose(words);
         sysdie("Unable to rewind words file");
+    }
     reported = false;
     if (hash == NULL)
         reported = true;
@@ -182,6 +184,7 @@ main(void)
     ok(38, !reported);
 
     hash_free(hash);
+    fclose(words);
 
     return 0;
 }
