@@ -1,4 +1,4 @@
-/* $Id: inet_aton-t.c 10099 2016-11-04 22:21:59Z iulius $
+/* $Id: inet_aton-t.c 10246 2018-02-16 21:12:42Z iulius $
  *
  * inet_aton test suite.
  *
@@ -6,14 +6,16 @@
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
+ * Copyright 2000-2001, 2004, 2017 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2007-2009, 2011
+ *     The Board of Trustees of the Leland Stanford Junior University
  *
- * The authors hereby relinquish any claim to any copyright that they may have
- * in this work, whether granted under contract or by operation of law or
- * international treaty, and hereby commit to the public, at large, that they
- * shall not, at any time in the future, seek to enforce any copyright in this
- * work against any person or entity, or prevent any person or entity from
- * copying, publishing, distributing or creating derivative works of this
- * work.
+ * Copying and distribution of this file, with or without modification, are
+ * permitted in any medium without royalty provided the copyright notice and
+ * this notice are preserved.  This file is offered as-is, without any
+ * warranty.
+ *
+ * SPDX-License-Identifier: FSFAP
  */
 
 #define LIBTEST_NEW_FORMAT 1
@@ -28,7 +30,7 @@ int test_inet_aton(const char *, struct in_addr *);
 
 
 static void
-test_addr(const char *string, unsigned long addr)
+test_addr(const char *string, uint32_t addr)
 {
     int success;
     struct in_addr in;
@@ -58,32 +60,32 @@ main(void)
     plan(92);
 
     test_addr(            "0.0.0.0", 0);
-    test_addr(     "127.0.0.000000", 0x7f000000UL);
-    test_addr(    "255.255.255.255", 0xffffffffUL);
-    test_addr(    "172.200.232.199", 0xacc8e8c7UL);
-    test_addr(            "1.2.3.4", 0x01020304UL);
+    test_addr(     "127.0.0.000000", 0x7f000000U);
+    test_addr(    "255.255.255.255", 0xffffffffU);
+    test_addr(    "172.200.232.199", 0xacc8e8c7U);
+    test_addr(            "1.2.3.4", 0x01020304U);
 
     test_addr(    "0x0.0x0.0x0.0x0", 0);
-    test_addr("0x7f.0x000.0x0.0x00", 0x7f000000UL);
-    test_addr("0xff.0xFf.0xFF.0xff", 0xffffffffUL);
-    test_addr("0xAC.0xc8.0xe8.0xC7", 0xacc8e8c7UL);
-    test_addr("0xAa.0xbB.0xCc.0xdD", 0xaabbccddUL);
-    test_addr("0xEe.0xfF.0.0x00000", 0xeeff0000UL);
-    test_addr("0x1.0x2.0x00003.0x4", 0x01020304UL);
+    test_addr("0x7f.0x000.0x0.0x00", 0x7f000000U);
+    test_addr("0xff.0xFf.0xFF.0xff", 0xffffffffU);
+    test_addr("0xAC.0xc8.0xe8.0xC7", 0xacc8e8c7U);
+    test_addr("0xAa.0xbB.0xCc.0xdD", 0xaabbccddU);
+    test_addr("0xEe.0xfF.0.0x00000", 0xeeff0000U);
+    test_addr("0x1.0x2.0x00003.0x4", 0x01020304U);
 
     test_addr(   "000000.00.000.00", 0);
-    test_addr(             "0177.0", 0x7f000000UL);
-    test_addr("0377.0377.0377.0377", 0xffffffffUL);
-    test_addr("0254.0310.0350.0307", 0xacc8e8c7UL);
-    test_addr("00001.02.3.00000004", 0x01020304UL);
+    test_addr(             "0177.0", 0x7f000000U);
+    test_addr("0377.0377.0377.0377", 0xffffffffU);
+    test_addr("0254.0310.0350.0307", 0xacc8e8c7U);
+    test_addr("00001.02.3.00000004", 0x01020304U);
 
-    test_addr(           "16909060", 0x01020304UL);
-    test_addr(      "172.062164307", 0xacc8e8c7UL);
-    test_addr(    "172.0xc8.0xe8c7", 0xacc8e8c7UL);
-    test_addr(              "127.1", 0x7f000001UL);
-    test_addr(         "0xffffffff", 0xffffffffUL);
-    test_addr(       "127.0xffffff", 0x7fffffffUL);
-    test_addr(     "127.127.0xffff", 0x7f7fffffUL);
+    test_addr(           "16909060", 0x01020304U);
+    test_addr(      "172.062164307", 0xacc8e8c7U);
+    test_addr(    "172.0xc8.0xe8c7", 0xacc8e8c7U);
+    test_addr(              "127.1", 0x7f000001U);
+    test_addr(         "0xffffffff", 0xffffffffU);
+    test_addr(       "127.0xffffff", 0x7fffffffU);
+    test_addr(     "127.127.0xffff", 0x7f7fffffU);
 
     test_fail(                 "");
     test_fail(     "Donald Duck!");
