@@ -1,4 +1,4 @@
-/*  $Id: uwildmat-t.c 9280 2011-07-17 19:36:24Z iulius $
+/*  $Id: uwildmat-t.c 10326 2019-02-04 14:22:34Z iulius $
 **
 **  wildmat test suite.
 **
@@ -8,7 +8,7 @@
 
 #include "clibrary.h"
 #include "inn/libinn.h"
-#include "libtest.h"
+#include "tap/basic.h"
 
 static void
 test_r(int n, const char *text, const char *pattern, bool matches)
@@ -58,7 +58,7 @@ test_v(int n, const char *text, bool matches)
 int
 main(void)
 {
-    test_init(187);
+    test_init(188);
 
     /* Basic wildmat features. */
     test_r(  1, "foo",            "foo",               true);
@@ -276,6 +276,7 @@ main(void)
                                                        false);
     test_v(186, "",                                    true);
     test_v(187, "a\303\251b\303\0c",                   false);
+    test_v(188, "two words",                           true);
     
     return 0;
 }
